/*
 * Copyright (c) 2019-2020, Sergey Bugaev <bugaevc@serenityos.org>
 *
 * SPDX-License-Identifier: BSD-2-Clause
 */

#pragma once

#include <AK/OwnPtr.h>
#include <LibMarkdown/Block.h>
#include <LibMarkdown/ContainerBlock.h>
#include <LibMarkdown/LineIterator.h>

namespace Markdown {

class List final : public Block {
public:
    List(Vector<OwnPtr<ContainerBlock>> items, bool is_ordered)
        : m_items(move(items))
        , m_is_ordered(is_ordered)
    {
    }
    virtual ~List() override { }

    virtual String render_to_html() const override;
    virtual String render_for_terminal(size_t view_width = 0) const override;

    static OwnPtr<List> parse(LineIterator& lines);

private:
    Vector<OwnPtr<ContainerBlock>> m_items;
    bool m_is_ordered { false };
};

}
